yakumo.constant

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Package yakumo :: Module constant |
[hide private]
[frames] | no frames]

# Module constant

source code

Constants

Variables | [hide private]
| UNDEF = ``'``__UNDEF__``'``
| __package__ = `None`

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Generated by Epydoc 3.0.1 on Sat Mar 4 23:02:23 2017 | http://epydoc.sourceforge.net